(* ------------------------------------------------------ *)
(*                   LOADCMOS.PAS                         *)
(* Laden des CMOS-Speicherinhalts aus dem Inhalt einer    *)
(* Datei                                                  *)
(*       (c) 1990 Ralf Randermann & TOOLBOX               *)
(* ------------------------------------------------------ *)
PROGRAM LoadCMOS;

USES CMOS;

CONST
  CRLF = #13#10;
  Bell = #7;

VAR
  LV, Work, LoadStart, LoadEnde : BYTE;
  DateiSize                     : LongInt;
  Datei                         : FILE OF BYTE;

BEGIN
  WriteLn('LoadCMOS Version 0.1', CRLF,
          'Laden des CMOS-Speicherinhalts aus dem ',
          'Inhalt einer Datei');
  IF ParamCount <> 1 THEN BEGIN
    WriteLn('Die Datei, aus der der CMOS-Speicherinhalt ',
            'gelesen werden soll, mu',CRLF,
            'als Parameter angegeben werden!', Bell);
    Halt;
  END;
  IF CMOSSize = 0 THEN BEGIN
    WriteLn('CMOS-Speicher nicht vorhanden oder nicht nach ',
            'AT-Standard lesbar!', Bell);
    Halt
  END;
{$I-}
  Assign(Datei, ParamStr(1));
  Reset(Datei);
  DateiSize := FileSize(Datei);
{$I+}
  IF IOResult > 0 THEN BEGIN
    WriteLn('Die angegebene Datei kann nicht zum Lesen ',
            'geffnet werden!', Bell);
    Halt;
  END;
  LoadStart :=  14;
  LoadEnde  := 127;
  CASE DateiSize OF
    50  : LoadEnde  := 63;
    64  : LoadStart := 64;
    114 : ;
    ELSE BEGIN
      WriteLn('In der angegebenen Datei wurde kein ',
              'CMOS-Speicherinhalt mit SaveCMOS abgelegt!',
               Bell);
      Halt;
    END;
  END;
  IF LoadStart >= CMOSSize THEN BEGIN
    WriteLn('Datei enthlt Expanded CMOS-Speicher !',
             Bell, CRLF,
            'Da nur Standard-AT CMOS-Speicher vorhanden, ',
            'kann Datei nicht geladen werden.');
    Halt;
  END;
  IF LoadEnde > CMOSSize THEN LoadEnde := 63;
  FOR LV := LoadStart TO LoadEnde DO BEGIN
    Read(Datei, Work);
    WriteCMOS(LV, Work)
  END;
  Close(Datei);
  WriteLn('CMOS-Speicherinhalt (von Byte ',
           LoadStart,' bis ',LoadEnde,
          ') aus Datei ', ParamStr(1), ' geladen.');
END.
(* ------------------------------------------------------ *)
(*               Ende von LOADCMOS.PAS                    *)
